function [r,sig] = LoadChiragTXT(fName,rInner)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                              %
% Layered Axisymmetric Plane Strain Model and Solver Toolbox                   %
%                                                                              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Charles Swanson, cswanson@pppl.gov
% 2022/05/19
%
% Loads in the stress from a TXT file compiled by Chirag Rana
%
%-------------------------------------------------------------------------------
% Usage:
% [r,sig] = LoadChiragTXT(fName,rInner)
%-------------------------------------------------------------------------------
% Inputs:
% fName(1,:)       Path name to the relevant SIG_TF.DAT output file
%-------------------------------------------------------------------------------
% Outputs:
% r(1,:)           Radii of the reported points (m)
% sig(1,:)         Stress of the reported points (Pa).
%-------------------------------------------------------------------------------
% Demo function
if (nargin==0)
  [r,sig] = LoadChiragTXT(...
  '~/SystemsStudies/CylinderLame/PlaneStrain/MATLAB/ChiragBenchmarks_Polygon/20_side1.txt',...
  0.33);
  figure();plot(r,sig);grid on;
  xlabel('Radius (m)');ylabel('Stress (Pa)');
  r = [];
  return
end

%-------------------------------------------------------------------------------
% Defaults
%-------------------------------------------------------------------------------

if ~exist(fName)
  fprintf('LoadChiragTXT reports that this file name does not exist: \n');
  fprintf('  %s \n',fName);
  r = [];
  return
end

fileID = fopen(fName);
fileArray = [];
line = fgetl(fileID);
line = fgetl(fileID);
while(~sum(line == -1))
  fileArray = [fileArray; str2num(line)];
  line = fgetl(fileID);
end

r  = fileArray(:,2)*1e-3 + rInner;
sig = fileArray(:,7)*1e6;

end