function [r,sR,sT,sZ] = LoadChiragCSV(fName,rInner)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                              %
% Layered Axisymmetric Plane Strain Model and Solver Toolbox                   %
%                                                                              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Charles Swanson, cswanson@pppl.gov
% 2022/02/16
%
% Loads in the stresses from a CSV file compiled by Chirag Rana
%
%-------------------------------------------------------------------------------
% Usage:
% [r,sR,sT,sZ] = LoadChiragCSV(fName,rInner)
%-------------------------------------------------------------------------------
% Inputs:
% fName(1,:)       Path name to the relevant SIG_TF.DAT output file
%-------------------------------------------------------------------------------
% Outputs:
% r(1,:)           Radii of the reported points (m)
% sR(1,:)          Radial stress of the reported points (Pa).
% sT(1,:)          Azimuthal stress of the reported points (Pa). 
% sZ(1,:)          Axial stress of the reported points (Pa). 
%-------------------------------------------------------------------------------
% Demo function
if (nargin==0)
  [r,sR] = LoadChiragCSV(...
  '~/SystemsStudies/CylinderLame/PlaneStrain/MATLAB/ChiragBenchmarks/S01_Shell.csv',...
  0.25);
  figure();plot(r,sR);grid on;
  xlabel('Radius (m)');ylabel('Radial stress (Pa)');
  r = [];
  return
end

%-------------------------------------------------------------------------------
% Defaults
%-------------------------------------------------------------------------------

if ~exist(fName)
  fprintf('LoadChiragCSV reports that this file name does not exist: \n');
  fprintf('  %s \n',fName);
  r = [];
  return
end

fileID = fopen(fName);
fileArray = [];
line = fgetl(fileID);
line = fgetl(fileID);
line = fgetl(fileID);
while(~sum(line == -1))
  fileArray = [fileArray; str2num(line)];
  line = fgetl(fileID);
end

r  = fileArray(:,1) + rInner;
sR = fileArray(:,2)*1e6;
sT = fileArray(:,3)*1e6;
sZ = fileArray(:,4)*1e6;

end