function [f,fIntA,fIntB] = NullBodyForceInts(r,layer,rLayers,nullInput)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                              %
% Layered Axisymmetric Plane Strain Model and Solver Toolbox                   %
%                                                                              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Charles Swanson, cswanson@pppl.gov
% 2022/04/06
%
% Produces zero-vectors instead of anything useful.
%
%-------------------------------------------------------------------------------
% Usage:
% [f,fIntA,fIntB] = NullBodyForceInts(r,layer,rLayers,dI)
%-------------------------------------------------------------------------------
% Inputs:
% r(1,:)           Radii of points at which to evaluate the force integrals (m)
% layer(1,:)       The layer number of each r(1,:) point
% rLayers(1,N+1)   The inner radii of each layer. rLayers(N+1) is the outer 
%                  radius of the outermost layer, layer N.
% nullInput(1,1)   Current carried by each layer (A)
%-------------------------------------------------------------------------------
% Outputs:
% f                Volumetric radial body force at each r point (N/m^3)
% fIntA            Integral of f between r and the next outer rLayer point. 
%                  This is used to transform the Lame A parameter at the outer
%                  point to the A parameter at r. (N/m^2)
% fIntB            Integral of f*r^2 between r and the next outer rLayer point. 
%                  This is used to transform the Lame B parameter at the outer
%                  point to the B parameter at r. (N/m)
%-------------------------------------------------------------------------------

f     = zeros(size(r));
fIntA = zeros(size(r));
fIntB = zeros(size(r));

end