function [sigR,sigTheta,sigZ] = StressStrain(epsR,epsTheta,epsZ,Ez,Et,nuzt,nut)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                              %
% Layered Axisymmetric Plane Strain Model and Solver Toolbox                   %
%                                                                              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Charles Swanson, cswanson@pppl.gov
% 2022/02/15
%
% Finds the stress at several radial points. Computes these quantities from the
% strain at these points. Assumes transverse-isotropic materials.
%
%-------------------------------------------------------------------------------
% Usage:
% TODOTODOTODO
%-------------------------------------------------------------------------------
% Inputs:
% epsR(1,:)        Radial strain
% epsTheta(1,:)    Azimuthal strain
% epsZ(1,:)        Axial strain
% Ez(1,:)          Axial Young's modulus (Pa)
% Et(1,:)          Transverse Young's modulus (Pa)
% nuzt(1,:)        Poisson's ratio in the axial-transverse direction
% nut(1,:)         Poisson's ratio in the transverse-transverse direction
%-------------------------------------------------------------------------------
% Outputs:
% sigR(1,:)        Radial stress (Pa).
% sigTheta(1,:)    Azimuthal stress (Pa).
% sigZ(1,:)        Axial stress (Pa).
%-------------------------------------------------------------------------------
% Demo function
if (nargin==0)
  TODO
  sigR = [];
  return
end
%-------------------------------------------------------------------------------
% Defaults
%-------------------------------------------------------------------------------

sigR     = ESt.*((1+nuSt).*AVec(1,:) - ...
 (1-nuSt).*AVec(2,:)./r.^2 + ...
  nuSzT.*epsZ);
  
sigTheta = ESt.*((1+nuSt).*AVec(1,:) + ...
  (1-nuSt).*AVec(2,:)./r.^2 + ...
  nuSzT.*epsZ);
  
sigZ     = ESz.*(epsZ + nutzBar.*(epsRPlot + epsThetaPlot));

end